//=============================================================================
//  
// Rough demo of Figurenotes Level 2 note rendering
//
//  http://musescore.org/en/project/shape_notes
//
//  Copyright (C)2010 Nicolas Froment (lasconic)
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License version 2.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//=============================================================================

var NOTE_NORMAL = 0;
var NOTE_7 = 2;

// Figurenotes default colours 
var colors = [new QColor(255,  0,  0),   // C
              new QColor(255,  0,  0),   // C#
              new QColor(148, 97, 51),   // D
              new QColor(148, 97, 51),   // D#
              new QColor(198,196,193),   // E
              new QColor(  0,143,216),   // F
              new QColor(  0,143,216),   // F#
              new QColor( 26, 25, 25),   // G
              new QColor( 26, 25, 25),   // G#
              new QColor(247,228,  0),   // A
              new QColor(247,228,  0),   // A#
              new QColor( 53,162, 17)];  // B

//---------------------------------------------------------
//    init
//---------------------------------------------------------

function init()
      {
      };

var form;

//---------------------------------------------------------
//    run
//    create gui from qt designer generated file test4.ui
//---------------------------------------------------------

function run()
      {
      var loader = new QUiLoader(null);
      var file   = new QFile(pluginPath + "/fign-l2.ui");
      file.open(QIODevice.OpenMode(QIODevice.ReadOnly, QIODevice.Text));
      form = loader.load(file, null);
      form.buttonBox.accepted.connect(accept);
      form.show();
      };


function accept()
      {
      var idx = -1;
      if (form.normal.checked)
            idx = NOTE_NORMAL;
      else if (form.notes7.checked)
            idx = NOTE_7;
      if (idx != -1)
            changeShape(idx);
      }

function changeShape(idx)
      {
      var degrees = [0, 0, 0, 0, 0, 0, 0]; 
      if (idx == NOTE_7)
        degrees = [6, 1, 10, 0, 7, 4, 5];
        
      var cursor = new Cursor(curScore);
      for (var staff = 0; staff < curScore.staves; ++staff) {
            cursor.staff = staff;
            for (var v = 0; v < 4; v++) {
                  cursor.voice = v;
                  cursor.rewind();  // set cursor to first chord/rest

                  while (!cursor.eos()) {
                        if (cursor.isChord()) {
                              var chord = cursor.chord();
                              var n     = chord.notes;
                              for (var i = 0; i < n; i++) {
                                    var note = chord.note(i);
                                    var npitch = note.pitch;
                                    
                                    note.color = new QColor(colors[note.pitch % 12]);
                                    
                                    note.noteHead = degrees[0];
                                    if(npitch >= 36) note.noteHead = degrees[1];
                                    if(npitch >= 48) note.noteHead = degrees[2];
                                    if(npitch >= 60) note.noteHead = degrees[3];
                                    if(npitch >= 72) note.noteHead = degrees[4];
                                    if(npitch >= 84) note.noteHead = degrees[5];
                                    if(npitch >= 96) note.noteHead = degrees[6];
                                    }
                              }
                        cursor.next();
                        }
                  }
            }
      }

var mscorePlugin = {
      menu: 'Plugins.Figurenotes L2',
      init: init,
      run:  run
      };

mscorePlugin;

